@@ -12,14 +12,27 @@ else
 	_LIB_EXEC="./acvp-parser"
 fi
 _LIB_IUT="testvectors"
+_LIB_IUT_PROD="testvectors-production"
 _LIB_REQ="testvector-request.json"
 _LIB_RESP="testvector-response.json"
+_LIB_EXPECTED="testvector-expected.json"
 #_LIB_OE="operational_environment.json"
 _LIB_REGRESSION="${_LIB_RESP}.regression.$$"
 
 failures=0
 local_failures=0
 
+EBITS=${EBITS:-"64 32"}
+ABITS=()
+for B in ${EBITS}; do
+    ABITS+=("_${B}_bit___ ")
+done
+EXEC_TYPES=${ABITS[@]}
+
+EXEC_TYPES__64_bit___=""
+EXEC_TYPES__32_bit___="CFLAGS=-m32 LDFLAGS=-m32"
+
+
 color()
 {
 	bg=0
@@ -47,7 +60,7 @@ color()
 
 echo_pass()
 {
-	echo $(color "green")[PASSED]$(color off) $@
+	echo $(color "green")[GENERATED]$(color off) $@
 }
 
 echo_fail()
@@ -152,6 +165,7 @@ exec_module()
 	local vendordir
 	local i
 	local j
+	local lib_iut_dir=${_LIB_IUT}
 
 	# If the script name contains "_regression" we switch into regression
 	# mode transparently
@@ -168,11 +182,16 @@ exec_module()
 
 	if [ ! -d "${_LIB_IUT}" ]
 	then
-		echo "Test vector base directory ${_LUB_IUT} not found"
-		return
+		if [ d "${_LIB_IUT_PROD}" ]
+		then
+			lib_iut_dir=${_LIB_IUT_PROD}
+		else
+			echo "Test vector base directory ${_LUB_IUT} / ${_LIB_IUT_PROD} not found"
+			return
+		fi
 	fi
 
-	for vendordir in ${_LIB_IUT}/*
+	for vendordir in ${lib_iut_dir}/*
 	do
 		if [ ! -d "$vendordir" ]
 		then
@@ -193,6 +212,7 @@ exec_module()
 			local vsid_dir=$(basename $dir)
 			local testid_dir=$(dirname $dir)
 			local found=0
+			local respfile=$_LIB_RESP
 
 			for j in $vsid
 			do
@@ -241,8 +261,13 @@ exec_module()
 
 			if [ ! -f $dir/$_LIB_RESP -a -n "$regression" -a x"$regression" != x"X" ]
 			then
-				echo_deact "Response file missing but regression testing requested - skipping $dir"
-				continue
+				if [ -f $dir/$_LIB_EXPECTED ]
+				then
+					respfile=$_LIB_EXPECTED
+				else
+					echo_deact "Response file missing but regression testing requested - skipping $dir"
+					continue
+				fi
 			fi
 
 			if [ ! -f $dir/$_LIB_REQ ]
@@ -261,7 +286,7 @@ exec_module()
 			then
 				# Do real testing
 
-				$_LIB_EXEC $module $dir/$_LIB_REQ $dir/$_LIB_RESP
+				$_LIB_EXEC $dir/$_LIB_REQ $dir/$_LIB_RESP
 				local ret=$?
 				if [ $ret -eq 95 ]	#EOPNOTSUPP
 				then
@@ -303,7 +328,7 @@ exec_module()
 					continue
 				fi
 
-				$_LIB_EXEC $module $dir/$_LIB_REQ $dir/$_LIB_REGRESSION
+				$_LIB_EXEC $dir/$_LIB_REQ $dir/$_LIB_REGRESSION
 				local ret=$?
 				if [ $ret -eq 95 ]	#EOPNOTSUPP
 				then
@@ -312,7 +337,7 @@ exec_module()
 				then
 					echo_fail "Execution for $dir failed (error code $ret) - executed command:"
 					echo "$_LIB_EXEC $dir/$_LIB_REQ $dir/$_LIB_REGRESSION"
-				elif ! $($_LIB_EXEC -e $dir/$_LIB_REGRESSION $dir/$_LIB_RESP > /dev/null); then
+				elif ! $($_LIB_EXEC -e $dir/$_LIB_REGRESSION $dir/$respfile > /dev/null); then
 					echo_fail "Regression testing for $dir"
 				else
 					echo_pass "Regression testing for $dir"
@@ -353,6 +378,7 @@ regression_test()
 cleanup()
 {
 	find $_LIB_IUT -name "$_LIB_REGRESSION" | xargs rm -f
+	find ${_LIB_IUT_PROD} -name "$_LIB_REGRESSION" | xargs rm -f
 	clean_tool
 }
 
