@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017 - 2019, Stephan Mueller <smueller@chronox.de>
+ * Copyright (C) 2017 - 2020, Stephan Mueller <smueller@chronox.de>
  *
  * License: see LICENSE file in root directory
  *
@@ -114,6 +114,7 @@ extern "C"
 #define ACVP_DSA		0x0000000100000000ULL
 #define ACVP_DH			0x0000000200000000ULL
 #define ACVP_EDDSA		0x0000000400000000ULL
+#define ACVP_ECDH_ED		0x0000000800000000ULL
 
 #define ACVP_DRBGCTR		0x0000001000000000ULL
 #define ACVP_DRBGHMAC		0x0000002000000000ULL
@@ -126,6 +127,7 @@ extern "C"
 
 #define ACVP_KDF_COMPONENT	0x0000100000000000ULL
 #define ACVP_KDF_800_108	0x0000200000000000ULL
+#define ACVP_HKDF		0x0000400000000000ULL
 #define ACVP_KDF_MASK		0x0000f00000000000ULL
 
 #define ACVP_KDF_108_DOUBLE_PIPELINE	0x0001000000000000ULL
