@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018 - 2019, Stephan Mueller <smueller@chronox.de>
+ * Copyright (C) 2018 - 2020, Stephan Mueller <smueller@chronox.de>
  *
  * License: see LICENSE file
  *
@@ -28,7 +28,7 @@
 #define ECDSA_DEF_CALLBACK_HELPER(name, flags, helper)			       \
 				DEF_CALLBACK_HELPER(ecdsa, name, flags, helper)
 
-struct ecdsa_backend *ecdsa_backend = NULL;
+static struct ecdsa_backend *ecdsa_backend = NULL;
 
 struct ecdsa_static_key {
 	void *key;
