@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017 - 2019, Stephan Mueller <smueller@chronox.de>
+ * Copyright (C) 2017 - 2020, Stephan Mueller <smueller@chronox.de>
  *
  * License: see LICENSE file
  *
@@ -28,7 +28,7 @@
 #include "parser_common.h"
 #include "parser_sha.h"
 
-struct sha_backend *sha_backend = NULL;
+static struct sha_backend *sha_backend = NULL;
 
 #define min(x, y)	(((size_t)x < (size_t)y) ? x : y)
 
